Class: Google::Cloud::OsConfig::V1::ListVulnerabilityReportsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/osconfig/v1/vulnerability.rb

Overview

A request message for listing vulnerability reports for all VM instances in the specified location.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns This field supports filtering by the severity level for the vulnerability. For a list of severity levels, see Severity levels for vulnerabilities.

The filter field follows the rules described in the AIP-160 guidelines as follows:

  • Filter for a specific severity type: you can list reports that contain vulnerabilities that are classified as medium by specifying vulnerabilities.details.severity:MEDIUM.

  • Filter for a range of severities : you can list reports that have vulnerabilities that are classified as critical or high by specifying vulnerabilities.details.severity:HIGH OR vulnerabilities.details.severity:CRITICAL.

Returns:

  • (::String)

    This field supports filtering by the severity level for the vulnerability. For a list of severity levels, see Severity levels for vulnerabilities.

    The filter field follows the rules described in the AIP-160 guidelines as follows:

    • Filter for a specific severity type: you can list reports that contain vulnerabilities that are classified as medium by specifying vulnerabilities.details.severity:MEDIUM.

    • Filter for a range of severities : you can list reports that have vulnerabilities that are classified as critical or high by specifying vulnerabilities.details.severity:HIGH OR vulnerabilities.details.severity:CRITICAL



236
237
238
239
# File 'proto_docs/google/cloud/osconfig/v1/vulnerability.rb', line 236

class ListVulnerabilityReportsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of results to return.

Returns:

  • (::Integer)

    The maximum number of results to return.



236
237
238
239
# File 'proto_docs/google/cloud/osconfig/v1/vulnerability.rb', line 236

class ListVulnerabilityReportsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A pagination token returned from a previous call to ListVulnerabilityReports that indicates where this listing should continue from.

Returns:

  • (::String)

    A pagination token returned from a previous call to ListVulnerabilityReports that indicates where this listing should continue from.



236
237
238
239
# File 'proto_docs/google/cloud/osconfig/v1/vulnerability.rb', line 236

class ListVulnerabilityReportsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource name.

Format: projects/{project}/locations/{location}/instances/-

For {project}, either project-number or project-id can be provided.

Returns:

  • (::String)

    Required. The parent resource name.

    Format: projects/{project}/locations/{location}/instances/-

    For {project}, either project-number or project-id can be provided.



236
237
238
239
# File 'proto_docs/google/cloud/osconfig/v1/vulnerability.rb', line 236

class ListVulnerabilityReportsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end