Class: Google::Cloud::OsConfig::V1::MonthlySchedule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/osconfig/v1/patch_deployments.rb

Overview

Represents a monthly schedule. An example of a valid monthly schedule is "on the third Tuesday of the month" or "on the 15th of the month".

Instance Attribute Summary collapse

Instance Attribute Details

#month_day::Integer

Returns Required. One day of the month. 1-31 indicates the 1st to the 31st day. -1 indicates the last day of the month. Months without the target day will be skipped. For example, a schedule to run "every month on the 31st" will not run in February, April, June, etc.

Note: The following fields are mutually exclusive: month_day, week_day_of_month. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Required. One day of the month. 1-31 indicates the 1st to the 31st day. -1 indicates the last day of the month. Months without the target day will be skipped. For example, a schedule to run "every month on the 31st" will not run in February, April, June, etc.

    Note: The following fields are mutually exclusive: month_day, week_day_of_month. If a field in that set is populated, all other fields in the set will automatically be cleared.



188
189
190
191
# File 'proto_docs/google/cloud/osconfig/v1/patch_deployments.rb', line 188

class MonthlySchedule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#week_day_of_month::Google::Cloud::OsConfig::V1::WeekDayOfMonth

Returns Required. Week day in a month.

Note: The following fields are mutually exclusive: week_day_of_month, month_day. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::OsConfig::V1::WeekDayOfMonth)

    Required. Week day in a month.

    Note: The following fields are mutually exclusive: week_day_of_month, month_day. If a field in that set is populated, all other fields in the set will automatically be cleared.



188
189
190
191
# File 'proto_docs/google/cloud/osconfig/v1/patch_deployments.rb', line 188

class MonthlySchedule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end